<!DOCTYPE html>
<html lang="en">
<head>
<meta charset="UTF-8">
<title>Choropleth Map with Interactive Filtering</title>
<style>
  /* Add some basic styling */
  body {
    font-family: Arial, sans-serif;
    margin: 0;
    padding: 0;
  }
  svg {
    width: 100%;
    height: 600px;
  }
  .legend {
    font-size: 12px;
  }
  .slider {
    width: 100%;
    margin: 20px 0;
  }
</style>
</head>
<body>
<!-- Create a container for the map -->
<div id="map"></div>
<!-- Add a range input for filtering -->
<input type="range" class="slider" id="populationFilter" min="0" max="100" value="0">
<span class="legend">Population Filter: <span id="filterValue"></span>%</span>

<!-- Load D3.js and create the map -->
<script src="https://d3js.org/d3.v7.min.js"></script>
<script>
  const svg = d3.select("#map")
    .append("svg")
    .attr("width", "100%")
    .attr("height", 600);

  const projection = d3.geoAlbersUsa()
    .scale(1200)
    .translate([500, 300]);

  const path = d3.geoPath().projection(projection);

  // Load the US states TopoJSON data
  d3.json("https://d3js.org/us-10m.v1.json").then(function(us) {
    svg.selectAll("path")
      .data(topojson.feature(us, us.objects.states).features)
      .enter().append("path")
      .attr("d", path)
      .attr("fill", "lightgray");

    // Load population data
    d3.csv("population_data.csv").then(function(data) {
      // Convert population strings to numbers
      data.forEach(function(d) {
        d.population = +d.population;
      });

      // Update map colors based on filter value
      function updateMap(filterValue) {
        svg.selectAll("path")
          .attr("fill", function(d) {
            const state = data.find(function(s) {
              return s.state === d.properties.name;
            });
            return state && state.population >= filterValue ? "steelblue" : "lightgray";
          });
      }

      // Initial map update
      updateMap(0);

      // Update map when filter changes
      d3.select("#populationFilter").on("input", function() {
        const filterValue = +this.value;
        updateMap(filterValue);
        d3.select("#filterValue").text(filterValue);
      });
    });
  });
</script>
</body>
</html>
